%define oname		aMule

%define date		20161207
%if %{date}
%define release		%mkrel -c git%{date} %{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		047a55c93f93760cc3534d3d60e5a9aa8c13cfa1
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%define tarballdir	%{version}
%endif

%define rel		2

Name:		amule
Version:	2.4.0
Release:	%{release}
Summary:	File sharing client compatible with eDonkey
License:	GPLv2
Group:		Networking/File transfer
URL:		http://amule.org
Source:		https://github.com/amule-project/amule/archive/%{tarballdir}/%{name}-%{version}%{?tarballgit}.tar.gz

BuildRequires:	binutils-devel
BuildRequires:	desktop-file-utils
BuildRequires:	boost-devel
BuildRequires:	gettext-devel
BuildRequires:	imagemagick
BuildRequires:	wxgtku3.0-devel >= 3.0
BuildRequires:	pkgconfig(cryptopp)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(geoip)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libupnp)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	readline-devel

%rename		amule1

%description
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

#------------------------------------------------------------------------------

%package	commandline
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name} = %{version}-%{release}

%description	commandline
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the command line tool to control aMule remotely (or locally:).

#------------------------------------------------------------------------------

%package	webserver
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name}

%description	webserver
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the webserver to control aMule remotely (or locally:).

#------------------------------------------------------------------------------
%prep
%setup -q -n %{name}-%{tarballver}

# fix SVN version tag name
sed -i -e 's|,\[SVN]|,\[2.4.0 (SVN %{date})]|' configure.ac

NOCONFIGURE=1 ./autogen.sh

%build
%configure2_5x \
    --with-wx-config=%{_bindir}/wx-config-3.0 \
    --with-boost \
    --with-denoise-level=0 \
    --disable-debug \
    --enable-amulecmd \
    --enable-amule-gui \
    --enable-webserver \
    --enable-cas \
    --enable-wxcas \
    --enable-alc \
    --enable-alcc \
    --enable-amule-daemon \
    --enable-optimize \
    --enable-geoip \
    --enable-xas
%make_build

%install
%make_install

for png in 128x128 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png amule.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_menudir}

# Fix wrong-script-end-of-line-encoding
perl -pi -e 's/\015$//' %{buildroot}%{_datadir}/doc/%{name}-%{version}/%{name}-win32.HOWTO.txt

mv %{buildroot}%{_bindir}/ed2k %{buildroot}%{_bindir}/ed2k-%{name}
rm -f %{buildroot}%{_datadir}/doc/%{name}-%{version}/man/.cvsignore
rm -rf %{buildroot}%{_datadir}/doc/%{oname}-%{version}
rm -f %{buildroot}%{_libdir}/xchat/plugins/xas.pl

desktop-file-install --vendor="" \
	--add-category="GTK" \
	--add-category="FileTransfer" \
	--dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*.desktop

%find_lang %{name} --with-man
%find_lang alc --with-man
%find_lang amulegui --with-man
%find_lang cas --with-man
%find_lang ed2k --with-man
%find_lang wxcas --with-man
%find_lang xas --with-man
cat alc.lang amulegui.lang cas.lang ed2k.lang wxcas.lang xas.lang  >> %{name}.lang

%find_lang alcc --with-man
%find_lang amulecmd --with-man
%find_lang amuled --with-man
cat alcc.lang amulecmd.lang amuled.lang  > %{name}-commandline.lang

%find_lang amuleweb --with-man
cat amuleweb.lang  > %{name}-webserver.lang

%post
update-alternatives --install %{_bindir}/ed2k ed2k %{_bindir}/ed2k-%{name} 5

%postun
update-alternatives --remove ed2k %{_bindir}/ed2k-%{name}

%files -f %{name}.lang
%doc docs/{ABOUT-NLS,AUTHORS,Changelog,README,README.Asio.txt,TODO}
%doc docs/{amulesig.txt,EC_Protocol.txt,license.txt,Releases.dia}
%license docs/COPYING
%exclude %{_docdir}/%{name}/INSTALL
%dir %{_datadir}/%{name}
%{_bindir}/%{name}*
%{_bindir}/autostart-xas
%{_bindir}/wxcas
%{_bindir}/cas
%{_bindir}/ed2k-%{name}
%{_bindir}/alc
%{_datadir}/%{name}/skins
%{_datadir}/cas
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/applications/alc.desktop
%{_datadir}/applications/wxcas.desktop
%{_datadir}/pixmaps/%{name}*.xpm
%{_datadir}/pixmaps/alc.xpm
%{_datadir}/pixmaps/wxcas.xpm
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/alc.1*
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man1/cas.1*
%{_mandir}/man1/ed2k.1*
%{_mandir}/man1/wxcas.1*
%{_mandir}/man1/xas.1*

%files commandline -f %{name}-commandline.lang
%{_bindir}/%{name}cmd
%{_bindir}/alcc
%{_bindir}/%{name}d
%{_mandir}/man1/alcc.1*
%{_mandir}/man1/%{name}cmd.1*
%{_mandir}/man1/%{name}d.1*

%files webserver -f %{name}-webserver.lang
%{_bindir}/%{name}web
%{_datadir}/%{name}/webserver/*
%{_mandir}/man1/amuleweb.1*


%changelog
* Sat Jun 03 2017 akien <akien> 2.4.0-0.git20161207.2.mga6
+ Revision: 1106082
- Rebuild for wxgtk 3.0.3.1

* Sat Jan 14 2017 daviddavid <daviddavid> 2.4.0-0.git20161207.1.mga6
+ Revision: 1081613
- update to latest git snapshot: 2.4.0-git20161207
- rebuild for new libcryptopp (mga#20120)

* Tue Oct 04 2016 daviddavid <daviddavid> 2.4.0-0.git20160926.1.mga6
+ Revision: 1058695
- update to latest git snapshot: 2.4.0-git20160926
- port to wxgtk3

* Sat Jul 09 2016 daviddavid <daviddavid> 2.4.0-0.git20160607.1.mga6
+ Revision: 1039947
- update to latest git snapshot: 2.4.0-git20160607
- rebuild against fixed libgd

* Wed Apr 27 2016 daviddavid <daviddavid> 2.4.0-0.git20160416.1.mga6
+ Revision: 1006892
- new version: 2.4.0-git20160416 (pre-release)
  * commit: 393acf5ce78dfdabd7316c44a78511db1c7bae74

* Wed Apr 27 2016 daviddavid <daviddavid> 2.4.0-0.git20160103.2.mga6
+ Revision: 1006876
- rebuild against libcryptopp 5.6.3 (fixes mga#18272)

* Mon Jan 04 2016 daviddavid <daviddavid> 2.4.0-0.git20160103.1.mga6
+ Revision: 919646
- new version: 2.4.0-git20160103 (pre-release)
  * commit: 13596819eeaf2334ad1a99981c6e1e2f8ddb953b
- update Source URL
- enable boost support

* Thu Sep 03 2015 cjw <cjw> 2.3.1-13.mga6
+ Revision: 872617
- rebuild with gcc 5

* Mon Feb 16 2015 oden <oden> 2.3.1-12.mga5
+ Revision: 815140
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 2.3.1-11.mga5
+ Revision: 739213
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 luigiwalser <luigiwalser> 2.3.1-10.mga5
+ Revision: 685710
- move rename macro usage to correct place in spec file

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sun Mar 30 2014 david-david <david-david> 2.3.1-8.mga5
+ Revision: 610360
- use better icon amule from tarball
- add BR imagemagick
- update License
- update link url for Source

* Sat Oct 19 2013 umeabot <umeabot> 2.3.1-7.mga4
+ Revision: 526042
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 fwang <fwang> 2.3.1-6.mga4
+ Revision: 435780
- rebuild for new libpng

* Tue May 28 2013 oden <oden> 2.3.1-5.mga4
+ Revision: 429280
- rebuilt against libgd.so.3

* Sun Mar 17 2013 lmenut <lmenut> 2.3.1-4.mga3
+ Revision: 403587
- rebuild for new rpm-mageia-setup (mga #9055)

* Fri Jan 11 2013 umeabot <umeabot> 2.3.1-3.mga3
+ Revision: 345533
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 sander85 <sander85> 2.3.1-2.mga3
+ Revision: 341146
- Rebuild with fixed libcryptopp

* Sat Jan 28 2012 kamil <kamil> 2.3.1-1.mga2
+ Revision: 202574
- new version 2.3.1
- use %%find_lang for man-pages
- clean .spec

* Mon Oct 31 2011 dmorgan <dmorgan> 2.3.1-0.rc2.1.mga2
+ Revision: 160520
- New version 2.3.1 rc2

* Wed Sep 21 2011 fwang <fwang> 2.3.1-0.rc1.4.mga2
+ Revision: 146203
- rebuild for new libpng
- rebuild for new libupnp

  + ahmad <ahmad>
    - Replace libgeoip-devel with geoip-devel

* Sun May 08 2011 dmorgan <dmorgan> 2.3.1-0.rc1.2.mga1
+ Revision: 95964
- Remove PLF Reason

* Sun May 08 2011 dmorgan <dmorgan> 2.3.1-0.rc1.1.mga1
+ Revision: 95963
- Fix file list
- Fix typo
- Update to 2.3.1 Rc1
- Do not apply patch0
- imported package amule

